@@ -22,12 +22,12 @@
 #include <pthread.h>
 #include <groonga.h>
 
+#include "util.h"
+
 #define DEFAULT_RECV_ENDPOINT "tcp://*:1234"
 #define DEFAULT_SEND_ENDPOINT "tcp://*:1235"
 #define SEND_WAIT 1000 /* 0.001sec */
 
-int print_error(const char *format, ...);
-
 #define CONST_STR_LEN(x) x, x ? sizeof(x) - 1 : 0
 
 typedef struct {
@@ -305,11 +305,14 @@ send_handler(void *zmq_send_sock, grn_ctx *ctx)
 
                 msgpack_sbuffer_destroy(&sbuf);
               }
+              grn_table_cursor_close(ctx, tc);
             }
           }
         }
+        grn_obj_unlink(ctx, table);
       }
     }
+    grn_table_cursor_close(ctx, cur);
   }
 }
 
@@ -324,9 +327,9 @@ send_to_httpd(void *arg)
       if (!(grn_ctx_init(&ctx, 0))) {
         grn_obj *db;
         if ((db = grn_db_open(&ctx, thd->db_path))) {
+          uint64_t hwm = 1;
+          zmq_setsockopt(zmq_send_sock, ZMQ_HWM, &hwm, sizeof(uint64_t));
           while (loop) {
-            uint64_t hwm = 1;
-            zmq_setsockopt(zmq_send_sock, ZMQ_HWM, &hwm, sizeof(uint64_t));
             send_handler(zmq_send_sock, &ctx);
           }
           grn_obj_close(&ctx, db);
@@ -460,10 +463,11 @@ static void
 usage(FILE *output)
 {
   fprintf(output,
-          "Usage: suggest-learner [options...] db_path\n"
+          "Usage: groonga-suggest-learner [options...] db_path\n"
           "options:\n"
           "  -r <recv endpoint>: recv endpoint (default: %s)\n"
-          "  -s <send endpoint>: send endpoint (default: %s)\n",
+          "  -s <send endpoint>: send endpoint (default: %s)\n"
+          "  -d                : daemonize\n",
           DEFAULT_RECV_ENDPOINT, DEFAULT_SEND_ENDPOINT);
 }
 
@@ -476,6 +480,7 @@ signal_handler(int sig)
 int
 main(int argc, char **argv)
 {
+  int daemon = 0;
   const char *recv_endpoint = DEFAULT_RECV_ENDPOINT,
              *send_endpoint = DEFAULT_SEND_ENDPOINT;
 
@@ -483,7 +488,7 @@ main(int argc, char **argv)
   {
     int ch;
 
-    while ((ch = getopt(argc, argv, "r:s:")) != -1) {
+    while ((ch = getopt(argc, argv, "r:s:d")) != -1) {
       switch(ch) {
       case 'r':
         recv_endpoint = optarg;
@@ -491,6 +496,9 @@ main(int argc, char **argv)
       case 's':
         send_endpoint = optarg;
         break;
+      case 'd':
+        daemon = 1;
+        break;
       }
     }
     argc -= optind; argv += optind;
@@ -503,6 +511,10 @@ main(int argc, char **argv)
     grn_ctx *ctx;
     msgpack_zone *mempool;
 
+    if (daemon) {
+      daemonize();
+    }
+
     grn_init();
 
     signal(SIGTERM, signal_handler);
