@@ -29,51 +29,51 @@ class RestoreTest < Test::Unit::TestCase
 
   def test_multiple_table_create
     assert_same_dump(<<-EOC)
-table_create users 0 ShortText
-table_create admin_users 0 users
+table_create users TABLE_HASH_KEY ShortText
+table_create admin_users TABLE_HASH_KEY users
 EOC
   end
 
   def test_order_of_table_create
     assert_same_dump(('a'..'z').to_a.shuffle.collect do |letter|
-                       "table_create #{letter} 0 ShortText\n"
+                       "table_create #{letter} TABLE_HASH_KEY ShortText\n"
                      end.join)
   end
 
   def test_column_create_short_text
     assert_same_dump(<<-EOC)
-table_create Entry 0 ShortText
-column_create Entry body 0 ShortText
+table_create Entry TABLE_HASH_KEY ShortText
+column_create Entry body COLUMN_SCALAR ShortText
 EOC
   end
 
   def test_column_create_int32
     assert_same_dump(<<-EOC)
-table_create Entry 0 ShortText
-column_create Entry body 0 Int32
+table_create Entry TABLE_HASH_KEY ShortText
+column_create Entry body COLUMN_SCALAR Int32
 EOC
   end
 
   def test_scaler_column_create
     assert_same_dump(<<-EOC)
-table_create Entry 0 ShortText
-column_create Entry body 0 ShortText
+table_create Entry TABLE_HASH_KEY ShortText
+column_create Entry body COLUMN_SCALAR ShortText
 EOC
   end
 
   def test_vector_column_create
     assert_same_dump(<<-EOC)
-table_create Entry 1 ShortText
-column_create Entry body 1 ShortText
+table_create Entry TABLE_PAT_KEY ShortText
+column_create Entry body COLUMN_VECTOR ShortText
 EOC
   end
 
   def test_index_column_create
     assert_same_dump(<<-EOC)
-table_create Entry 0 ShortText
-column_create Entry body 0 ShortText
-table_create Terms 129 ShortText --default_tokenizer TokenBigram
-column_create Terms entry_body 2 Entry body
+table_create Entry TABLE_HASH_KEY ShortText
+column_create Entry body COLUMN_SCALAR ShortText
+table_create Terms TABLE_PAT_KEY|KEY_NORMALIZE ShortText --default_tokenizer TokenBigram
+column_create Terms entry_body COLUMN_INDEX Entry body
 EOC
   end
 
@@ -81,10 +81,10 @@ EOC
     body = "作成するテーブルを語彙表として使用する場合、" +
            "文字列を分割するトークナイザを指定します。"
     assert_same_dump(<<-EOC)
-table_create Entry 0 ShortText
-column_create Entry body 0 ShortText
-table_create Terms 129 ShortText --default_tokenizer TokenBigram
-column_create Terms entry_body 2 Entry body
+table_create Entry TABLE_HASH_KEY ShortText
+column_create Entry body COLUMN_SCALAR ShortText
+table_create Terms TABLE_PAT_KEY|KEY_NORMALIZE ShortText --default_tokenizer TokenBigram
+column_create Terms entry_body COLUMN_INDEX Entry body
 load --table Entry
 [
 ["_key","body"],
@@ -95,20 +95,20 @@ EOC
 
   def test_table_with_key_index_column
     assert_same_dump(<<-EOC)
-table_create Bookmarks 0 ShortText
-table_create Terms 129 ShortText --default_tokenizer TokenBigram
-column_create Terms bookmarks_key 2 Bookmarks _key
+table_create Bookmarks TABLE_HASH_KEY ShortText
+table_create Terms TABLE_PAT_KEY|KEY_NORMALIZE ShortText --default_tokenizer TokenBigram
+column_create Terms bookmarks_key COLUMN_INDEX Bookmarks _key
 EOC
   end
 
   def test_no_tokenizer_table_with_index_column
     assert_same_dump(<<-EOC)
-table_create People 0 ShortText
-column_create People name 0 ShortText
-table_create Bookmarks 0 ShortText
-column_create Bookmarks title 0 ShortText
-column_create Bookmarks people 1 People
-column_create People bookmarks 2 Bookmarks people
+table_create People TABLE_HASH_KEY ShortText
+column_create People name COLUMN_SCALAR ShortText
+table_create Bookmarks TABLE_HASH_KEY ShortText
+column_create Bookmarks title COLUMN_SCALAR ShortText
+column_create Bookmarks people COLUMN_VECTOR People
+column_create People bookmarks COLUMN_INDEX Bookmarks people
 load --table People
 [
 ["_key","name"],
@@ -127,10 +127,10 @@ EOC
     body = "作成するテーブルを語彙表として使用する場合、" +
            "文字列を分割するトークナイザを指定します。"
     commands = <<-EOC
-table_create Terms 129 ShortText --default_tokenizer TokenBigram
-table_create Entry 0 ShortText
-column_create Entry body 0 ShortText
-column_create Terms entry_body 2 Entry body
+table_create Terms TABLE_PAT_KEY|KEY_NORMALIZE ShortText --default_tokenizer TokenBigram
+table_create Entry TABLE_HASH_KEY ShortText
+column_create Entry body COLUMN_SCALAR ShortText
+column_create Terms entry_body COLUMN_INDEX Entry body
 load --table Entry
 [
 {"_key":"gcc","body":"#{body}"}
@@ -138,10 +138,10 @@ load --table Entry
 EOC
 
     assert_dump(<<-EOD, commands)
-table_create Terms 129 ShortText --default_tokenizer TokenBigram
-table_create Entry 0 ShortText
-column_create Entry body 0 ShortText
-column_create Terms entry_body 2 Entry body
+table_create Terms TABLE_PAT_KEY|KEY_NORMALIZE ShortText --default_tokenizer TokenBigram
+table_create Entry TABLE_HASH_KEY ShortText
+column_create Entry body COLUMN_SCALAR ShortText
+column_create Terms entry_body COLUMN_INDEX Entry body
 load --table Entry
 [
 ["_key","body"],
@@ -155,11 +155,11 @@ EOD
     body = "作成するテーブルを語彙表として使用する場合、" +
            "文字列を分割するトークナイザを指定します。"
     assert_same_dump(<<-EOC)
-table_create Entry 0 ShortText
-column_create Entry title 0 ShortText
-column_create Entry body 0 ShortText
-table_create Terms 129 ShortText --default_tokenizer TokenBigram
-column_create Terms entry_body 2 Entry title,body
+table_create Entry TABLE_HASH_KEY ShortText
+column_create Entry title COLUMN_SCALAR ShortText
+column_create Entry body COLUMN_SCALAR ShortText
+table_create Terms TABLE_PAT_KEY|KEY_NORMALIZE ShortText --default_tokenizer TokenBigram
+column_create Terms entry_body COLUMN_INDEX Entry title,body
 load --table Entry
 [
 ["_key","title","body"],
@@ -170,8 +170,8 @@ EOC
 
   def test_load
     assert_same_dump(<<-EOC)
-table_create commands 1 ShortText
-column_create commands body 0 ShortText
+table_create commands TABLE_PAT_KEY ShortText
+column_create commands body COLUMN_SCALAR ShortText
 load --table commands
 [
 ["_key","body"],
@@ -183,7 +183,7 @@ EOC
 
   def test_load_to_value_pseudo_column_of_hash_table
     assert_same_dump(<<-EOC)
-table_create users 0 ShortText Int32
+table_create users TABLE_HASH_KEY ShortText Int32
 load --table users
 [
 ["_key","_value"],
@@ -195,7 +195,7 @@ EOC
 
   def test_load_to_value_pseudo_column_of_patricia_table
     assert_same_dump(<<-EOC)
-table_create users 1 ShortText Int32
+table_create users TABLE_PAT_KEY ShortText Int32
 load --table users
 [
 ["_key","_value"],
@@ -207,7 +207,7 @@ EOC
 
   def test_load_to_value_pseudo_column_of_array_table
     assert_same_dump(<<-EOC)
-table_create users 3 --value_type Int32
+table_create users TABLE_NO_KEY --value_type Int32
 load --table users
 [
 ["_id","_value"],
@@ -219,8 +219,8 @@ EOC
 
   def test_load_reference_key_to_value_pseudo_column
     assert_same_dump(<<-EOC)
-table_create groups 0 ShortText
-table_create users 0 ShortText groups
+table_create groups TABLE_HASH_KEY ShortText
+table_create users TABLE_HASH_KEY ShortText groups
 load --table groups
 [
 ["_key"],
@@ -238,9 +238,9 @@ EOC
 
   def test_load_reference_id_to_value_pseudo_column
     assert_same_dump(<<-EOC)
-table_create groups 3
-column_create groups name 0 ShortText
-table_create users 0 ShortText groups
+table_create groups TABLE_NO_KEY
+column_create groups name COLUMN_SCALAR ShortText
+table_create users TABLE_HASH_KEY ShortText groups
 load --table groups
 [
 ["_id","name"],
@@ -258,8 +258,8 @@ EOC
 
   def test_load_to_array
     assert_same_dump(<<-EOC)
-table_create commands 3
-column_create commands body 0 ShortText
+table_create commands TABLE_NO_KEY
+column_create commands body COLUMN_SCALAR ShortText
 load --table commands
 [
 ["_id","body"],
@@ -271,8 +271,8 @@ EOC
 
   def test_int32_load
     assert_same_dump(<<-EOC)
-table_create commands 1 ShortText
-column_create commands body 0 Int32
+table_create commands TABLE_PAT_KEY ShortText
+column_create commands body COLUMN_SCALAR Int32
 load --table commands
 [
 ["_key","body"],
@@ -284,8 +284,8 @@ EOC
 
   def test_vector_empty_load
     assert_same_dump(<<-EOC)
-table_create commands 1 ShortText
-column_create commands body 1 ShortText
+table_create commands TABLE_PAT_KEY ShortText
+column_create commands body COLUMN_VECTOR ShortText
 load --table commands
 [
 ["_key","body"],
@@ -296,8 +296,8 @@ EOC
 
   def test_vector_string_load
     assert_same_dump(<<-EOC)
-table_create commands 1 ShortText
-column_create commands body 1 ShortText
+table_create commands TABLE_PAT_KEY ShortText
+column_create commands body COLUMN_VECTOR ShortText
 load --table commands
 [
 ["_key","body"],
@@ -308,8 +308,8 @@ EOC
 
   def test_vector_int32_load
     assert_same_dump(<<-EOC)
-table_create commands 1 ShortText
-column_create commands body 1 Int32
+table_create commands TABLE_PAT_KEY ShortText
+column_create commands body COLUMN_VECTOR Int32
 load --table commands
 [
 ["_key","body"],
@@ -320,10 +320,10 @@ EOC
 
   def test_load_with_text_reference_key
     assert_same_dump(<<EOGQTP)
-table_create users 0 ShortText
-table_create comments 1 ShortText
-column_create comments text 0 ShortText
-column_create comments author 0 users
+table_create users TABLE_HASH_KEY ShortText
+table_create comments TABLE_PAT_KEY ShortText
+column_create comments text COLUMN_SCALAR ShortText
+column_create comments author COLUMN_SCALAR users
 load --table users
 [
 ["_key"],
@@ -341,10 +341,10 @@ EOGQTP
 
   def test_load_with_vector_text_reference_key
     assert_same_dump(<<EOGQTP)
-table_create users 0 ShortText
-table_create comments 1 ShortText
-column_create comments text 0 ShortText
-column_create comments author 1 users
+table_create users TABLE_HASH_KEY ShortText
+table_create comments TABLE_PAT_KEY ShortText
+column_create comments text COLUMN_SCALAR ShortText
+column_create comments author COLUMN_VECTOR users
 load --table users
 [
 ["_key"],
@@ -361,11 +361,11 @@ EOGQTP
 
   def test_load_with_int32_reference_key
     assert_same_dump(<<EOGQTP)
-table_create users 0 Int32
-column_create users name 0 ShortText
-table_create comments 1 ShortText
-column_create comments text 0 ShortText
-column_create comments author 0 users
+table_create users TABLE_HASH_KEY Int32
+column_create users name COLUMN_SCALAR ShortText
+table_create comments TABLE_PAT_KEY ShortText
+column_create comments text COLUMN_SCALAR ShortText
+column_create comments author COLUMN_SCALAR users
 load --table users
 [
 ["_key","name"],
@@ -383,11 +383,11 @@ EOGQTP
 
   def test_load_with_reference_id
     assert_same_dump(<<EOGQTP)
-table_create users 3
-column_create users name 0 ShortText
-table_create comments 1 ShortText
-column_create comments text 0 ShortText
-column_create comments author 0 users
+table_create users TABLE_NO_KEY
+column_create users name COLUMN_SCALAR ShortText
+table_create comments TABLE_PAT_KEY ShortText
+column_create comments text COLUMN_SCALAR ShortText
+column_create comments author COLUMN_SCALAR users
 load --table users
 [
 ["_id","name"],
@@ -405,11 +405,11 @@ EOGQTP
 
   def test_load_with_vector_int32_reference_key
     assert_same_dump(<<EOGQTP)
-table_create users 0 Int32
-column_create users name 0 ShortText
-table_create comments 1 ShortText
-column_create comments text 0 ShortText
-column_create comments author 1 users
+table_create users TABLE_HASH_KEY Int32
+column_create users name COLUMN_SCALAR ShortText
+table_create comments TABLE_PAT_KEY ShortText
+column_create comments text COLUMN_SCALAR ShortText
+column_create comments author COLUMN_VECTOR users
 load --table users
 [
 ["_key","name"],
@@ -426,11 +426,11 @@ EOGQTP
 
   def test_load_with_vector_reference_id
     assert_same_dump(<<EOGQTP)
-table_create users 3
-column_create users name 0 ShortText
-table_create comments 1 ShortText
-column_create comments text 0 ShortText
-column_create comments author 1 users
+table_create users TABLE_NO_KEY
+column_create users name COLUMN_SCALAR ShortText
+table_create comments TABLE_PAT_KEY ShortText
+column_create comments text COLUMN_SCALAR ShortText
+column_create comments author COLUMN_VECTOR users
 load --table users
 [
 ["_id","name"],
@@ -447,9 +447,9 @@ EOGQTP
 
   def test_load_chained_subtables
     assert_same_dump(<<EOGQTP)
-table_create words 0 ShortText
-table_create japanese 0 words
-table_create noun 0 japanese
+table_create words TABLE_HASH_KEY ShortText
+table_create japanese TABLE_HASH_KEY words
+table_create noun TABLE_HASH_KEY japanese
 load --table words
 [
 ["_key"],
@@ -479,7 +479,7 @@ EOGQTP
 [[0,0.0,0.0],[[[2],[["_id","UInt32"],["_key","ShortText"]],[1,"hayamiz"],[3,"mori"]]]]
 [[0,0.0,0.0],true]
 EXPECTED
-table_create users 0 ShortText
+table_create users TABLE_HASH_KEY ShortText
 load --table users
 [
 {"_key":"hayamiz"},
@@ -500,8 +500,8 @@ COMMANDS
 [[0,0.0,0.0],[[[2],[["_id","UInt32"],["name","ShortText"]],[1,"hayamiz"],[3,"mori"]]]]
 [[0,0.0,0.0],true]
 EXPECTED
-table_create users 3
-column_create users name 0 ShortText
+table_create users TABLE_NO_KEY
+column_create users name COLUMN_SCALAR ShortText
 load --table users
 [
 {"name":"hayamiz"},
@@ -515,11 +515,11 @@ COMMANDS
 
   def test_load_unsequential_array_table
     assert_same_dump(<<COMMANDS)
-table_create users 3
-column_create users name 0 ShortText
-table_create blog_entries 3
-column_create blog_entries body 0 ShortText
-column_create blog_entries author 0 users
+table_create users TABLE_NO_KEY
+column_create users name COLUMN_SCALAR ShortText
+table_create blog_entries TABLE_NO_KEY
+column_create blog_entries body COLUMN_SCALAR ShortText
+column_create blog_entries author COLUMN_SCALAR users
 load --table users
 [
 ["_id","name"],
@@ -552,15 +552,15 @@ COMMANDS
 
     assert_equal(<<-EXPECTED, result)
 [[0,0.0,0.0],[[[3],[["author.name","ShortText"]],["hayamiz"],["ryoqun"],["mori"]]]]
-[[0,0.0,0.0]]
+[[0,0.0,0.0],true]
 EXPECTED
   end
 
   def test_view
     assert_same_dump(<<COMMANDS)
-table_create View 4
-table_create FreePrograms 1 ShortText
-table_create NonFreePrograms 1 ShortText
+table_create View TABLE_VIEW
+table_create FreePrograms TABLE_PAT_KEY ShortText
+table_create NonFreePrograms TABLE_PAT_KEY ShortText
 view_add View FreePrograms
 view_add View NonFreePrograms
 load --table FreePrograms
