@@ -26,8 +26,20 @@ class StatusTest < Test::Unit::TestCase
     teardown_local_database
   end
 
-  def test_status_exit_successfully
+  def test_exit_successfully
     output = run_groonga(@database_path, "status")
     assert_predicate($?, :success?)
   end
+
+  def test_command_version
+    output = run_groonga(@database_path, "status", "--command_version", "1")
+    rc, result = JSON.parse(output)
+    assert_equal(1, result["command_version"])
+  end
+
+  def test_unsupported_command_version
+    output = run_groonga(@database_path, "status", "--command_version", "10000")
+    rc, result = JSON.parse(output)
+    assert_equal(Result::UNSUPPORTED_COMMAND_VERSION, rc[0])
+  end
 end
